[tool.poetry]
name = "{{ PKG.NAME }}"
version = "0.6.2.dev1"
description = "{{ PKG.DESCRIPTION }}"
authors = ["Jacob Stewart <jacob@swarmauri.com>"]
license = "Apache-2.0"
readme = "README.md"
repository = "http://github.com/swarmauri/swarmauri-sdk/pkgs/{{ PROJ.ROOT }}/{{ PKG.NAME }}/"
classifiers = [
    "License :: OSI Approved :: Apache Software License",
    "Natural Language :: English",
    "Programming Language :: Python :: 3.10",
    "Programming Language :: Python :: 3.11",
    "Programming Language :: Python :: 3.12",
    "Programming Language :: Python :: 3.13",
    "Development Status :: 3 - Alpha"
]
keywords = []

[tool.poetry.dependencies]
python = ">=3.10,<3.13"

# Swarmauri
swarmauri_core = {git = "https://github.com/swarmauri/swarmauri-sdk.git", branch = "mono/dev", subdirectory = "pkgs/core"}
swarmauri_base = {git = "https://github.com/swarmauri/swarmauri-sdk.git", branch = "mono/dev", subdirectory = "pkgs/base"}
swarmauri_standard = {git = "https://github.com/swarmauri/swarmauri-sdk.git", branch = "mono/dev", subdirectory = "pkgs/swarmauri_standard"}

# Dependencies
<!-- include additional dependencies here -->
{% if PKG.PACKAGE_REQUIRES %}
{% for required in PACKAGE_REQUIRES %}
{{ required.NAME }} = "{{ required.VERSION }}"
{% endfor %}
{% endif %}


[tool.poetry.group.dev.dependencies]
flake8 = "^7.0"
pytest = "^8.0"
pytest-asyncio = ">=0.24.0"
pytest-xdist = "^3.6.1"
pytest-json-report = "^1.5.0"
python-dotenv = "*"
requests = "^2.32.3"

[build-system]
requires = ["poetry-core>=1.0.0"]
build-backend = "poetry.core.masonry.api"

[tool.pytest.ini_options]

markers = [
    "unit: Unit tests",
    "i9n: Integration tests",
    "r8n: Regression tests",
    "xfail: Expected failures",
    "xpass: Expected passes"
]
log_cli = true
log_cli_level = "INFO"
log_cli_format = "%(asctime)s [%(levelname)s] %(message)s"
log_cli_date_format = "%Y-%m-%d %H:%M:%S"
asyncio_default_fixture_loop_scope = "function"

{%- set grouped_modules = PKG.MODULES | groupby('EXTRAS.RESOURCE_KIND') %}
{%- for kind, mods in grouped_modules %}
[tool.poetry.plugins."swarmauri.{{ kind }}"]
{%- for mod in mods %}
{{ mod.NAME }} = "{{ PKG.NAME }}:{{ mod.NAME }}"
{%- endfor %}
{%- endfor %}

